starcluster.commands.completers.InstanceCompleter

Package starcluster :: Package commands :: Module completers :: Class InstanceCompleter |
[hide private]
[frames] | no frames]

# Class InstanceCompleter

source code

Returns a list of all instance ids as completion options

Instance Methods | [hide private]
_completer(self) | source code
Inherited from `Completer` (private): `_prep_for_completion` Inherited from `base.CmdBase`: `addopts`, `cancel_command`, `catch_ctrl_c`, `warn_experimental` Inherited from `base.CmdBase` (private): `_positive_int` Inherited from `optcomplete.CmdComplete`: `autocomplete` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| show_dns_names = `False`
Inherited from `Completer` (private): `_cfg` Inherited from `base.CmdBase`: `gopts`, `gparser`, `opts`, `parser`, `subcmds_map` Inherited from `base.CmdBase` (private): `_cm`, `_ec2`, `_nm`, `_s3`

Properties | [hide private]
Inherited from `Completer`: `completer` Inherited from `base.CmdBase`: `cfg`, `cluster_manager`, `cm`, `comp_words`, `ec2`, `goptions_dict`, `log`, `nm`, `node_manager`, `options_dict`, `s3`, `specified_options_dict` Inherited from `object`: `__class__`